@@ -24,7 +24,7 @@ function build_and_install_beta() {
     exit 1
   fi
 
-  git clone --depth 1 --no-tags $BASHUNIT_GIT_REPO temp_bashunit 2>/dev/null
+  git clone --depth 1 --no-tags "$BASHUNIT_GIT_REPO" temp_bashunit 2>/dev/null
   cd temp_bashunit
   ./build.sh >/dev/null
   local latest_commit=$(git rev-parse --short=7 HEAD)
@@ -70,7 +70,7 @@ BASHUNIT_GIT_REPO="https://github.com/TypedDevs/bashunit"
 if is_git_installed; then
     LATEST_BASHUNIT_VERSION="$(get_latest_tag "$BASHUNIT_GIT_REPO")"
 else
-    LATEST_BASHUNIT_VERSION="0.18.0"
+    LATEST_BASHUNIT_VERSION="0.19.0"
 fi
 TAG="$LATEST_BASHUNIT_VERSION"
 
