@@ -3,9 +3,8 @@
 function console_header::print_version_with_env() {
   local filter=${1:-}
   local files=("${@:2}")
-  local should_print_ascii="true"
 
-  if [[ "$BASHUNIT_SHOW_HEADER" != "$should_print_ascii" ]]; then
+  if ! env::is_show_header_enabled; then
     return
   fi
 
@@ -26,7 +25,7 @@ function console_header::print_version() {
     total_tests=$(helpers::find_total_tests "$filter" "${files[@]}")
   fi
 
-  if [[ $BASHUNIT_HEADER_ASCII_ART == true ]]; then
+  if env::is_header_ascii_art_enabled; then
     cat <<EOF
  _               _                   _
 | |__   __ _ ___| |__  __ __ ____ (_) |_
@@ -61,30 +60,36 @@ Arguments:
   If you use wildcards, bashunit will run any tests it finds.
 
 Options:
-  -a|--assert <function ...args>
+  -a, --assert <function ...args>
     Run a core assert function standalone without a test context.
 
+  -e, --env, --boot <file-path>
+    Load a custom file, overriding the existing .env variables or loading a file with global functions.
+
+  -f, --filter <filter>
+    Filters the tests to run based on the test name.
+
+  -l, --log-junit <out.xml>
+    Create a report JUnit XML file that contains information about the test results.
+
+  -p, --parallel || --no-parallel [default]
+    Run each test in child process, randomizing the tests execution order.
+
+  -r, --report-html <out.html>
+    Create a report HTML file that contains information about the test results.
+
+  -s, --simple || --detailed [default]
+    Enables simple or detailed output to the console.
+
+  -S, --stop-on-failure
+    Force to stop the runner right after encountering one failing test.
+
   --debug <?file-path>
     Print all executed shell commands to the terminal.
     If a file-path is passed, it will redirect the output to that file.
 
-  -e|--env|--load <file-path>
-    Load a custom file, overriding the existing .env variables or loading a file with global functions.
-
-  -f|--filter <filter>
-    Filters the tests to run based on the test name.
-
-  -l|--log-junit <out.xml>
-    Create a report JUnit XML file that contains information about the test results.
-
-  -r|--report-html <out.html>
-    Create a report HTML file that contains information about the test results.
-
-  -s|simple || -v|verbose
-    Enables simplified or verbose output to the console.
-
-  -S|--stop-on-failure
-    Force to stop the runner right after encountering one failing test.
+  -vvv, --verbose
+    Display internal details for each test.
 
   --version
     Displays the current version of bashunit.
@@ -92,7 +97,7 @@ Options:
   --upgrade
     Upgrade to latest version of bashunit.
 
-  --help
+  -h, --help
     This message.
 
 See more: https://bashunit.typeddevs.com/command-line
